@@ -114,9 +114,12 @@ binaryChoice <- function(formula, subset, na.action,
                                         # model frame will be wrong if called from inside a function
                                         # inside a function (sorry, I can't understand it either :-(
    mf <- eval(mf, envir=parent.frame())
-   if (method == "model.frame")
+   if( method == "model.frame" ) {
+      if( !is.null( list(...)$weights ) ) {
+         mf[[ "(weights)" ]] <- list(...)$weights
+      }
        return(mf)
-   else if (method != "ML")
+   } else if (method != "ML")
        warning("method = ", method, " is not supported. Using \"ML\"")
    mt <- attr(mf, "terms")
    Y <- model.response( mf )
@@ -175,7 +178,7 @@ binaryChoice <- function(formula, subset, na.action,
                                levels=YLevels)),
                            # We estimate probability for Y == levels[2]
                            # as opposite of levels[1]
-               df=nObs - nParam,
+               df.residual = nObs - sum( activePar( estimation ) ),
                call=cl,
                terms=mt,
                x=switch(x, "1"=list(X), "0"=NULL),
